package com.cesgroup.kingkong.web;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.cesgroup.common.utils.*;
import com.cesgroup.kingkong.commons.utils.JwtUtils;
import com.cesgroup.kingkong.core.security.model.JwtUser;
import com.cesgroup.kingkong.entity.IPCheckEntity;
import com.cesgroup.kingkong.interceptor.RequiredPermission;
import com.cesgroup.kingkong.service.IPCheckService;
import com.cesgroup.kingkong.service.SecretKeyService;
import org.apache.commons.collections.MapUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

/**
 * @program: kyb-search
 * @description: token
 * @author: Wanjianbin
 * @create: 2019-08-27 15:32
 **/
@RestController
@RequestMapping("/token")
public class TokenController extends BaseServiceController<IPCheckEntity, IPCheckService> {

    @Autowired
    SecretKeyService secretKeyService;

    @PostMapping("/getToken")
    @RequiredPermission
    public RestAPIResult<Object> getToken(String sign) throws Exception {
//        String ip = ApiResultUtil.getUserIP(request);
        Map<String, Object> params = RSAEncryptUtil.resolveParamsForSign(sign, secretKeyService.getById(2));
        String ip = MapUtils.getString(params, "randomStr");
        IPCheckEntity ipCheckEntity = this.service.getOne(new QueryWrapper<IPCheckEntity>().eq("ip_address", ip));
        RestAPIResult<Object> panResult = new RestAPIResult<Object>(secretKeyService);
        if(ipCheckEntity == null){
            panResult.error(ApiResponseEnum.AUTH_IP_ERROR.getErrMsg());
        }else {
            JwtUser user = new JwtUser();
            user.setId(ipCheckEntity.getId().toString());
            user.setUserName(ip);
            user.setLoginName(ip);

            String token = JwtUtils.createJwtBySimpleUser(user, 1000 * 60 * 60 * 24, ApiResponseEnum.AUTH_CENTER_SERVICE);
            ipCheckEntity.setToken(token);
            ipCheckEntity.setLastTokenTime(new Date().getTime());
            this.service.updateById(ipCheckEntity);
            panResult.setRespData(token);
        }
        return panResult;
    }

    @GetMapping("/applyToken")
    @RequiredPermission
    public RestAPIResult<Object> applyToken(String sign) throws Exception {
        Map<String, Object> params = RSAEncryptUtil.resolveParamsForSign(sign, secretKeyService.getById(2));
        String applyDate = MapUtils.getString(params, "applyDate");
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        String today = sdf.format(new Date());
        RestAPIResult<Object> panResult = new RestAPIResult<Object>(secretKeyService);
        if(today.equals(applyDate)){
            Map<String, Object> result = new HashMap<>();
            result.put("today", today);
            String randomStr = RandomUtil.getStringRandom(12, null);
            result.put("randomStr", randomStr);

            IPCheckEntity ipCheckEntity = new IPCheckEntity();
            ipCheckEntity.setId(1);
            ipCheckEntity.setIpAddress(randomStr);
            this.service.updateById(ipCheckEntity);

            panResult.setRespData(result);
        }else {
            panResult.error(ApiResponseEnum.APPLY_TOKEN_ERROR.getErrMsg());
        }
        return panResult;
    }


    @RequestMapping("/test")
    public ApiResponse test(){
        return ApiResultUtil.getApiResponse(null, ApiResponseEnum.SUCCESS);
    }
}
